@@ -6,7 +6,7 @@ Swagger2 - Swagger RESTful API Documentation
 
 =head1 VERSION
 
-0.39
+0.40
 
 =head1 DESCRIPTION
 
@@ -63,7 +63,7 @@ use constant CACHE_DIR => $ENV{SWAGGER2_CACHE_DIR}
 
 use constant DEBUG => $ENV{SWAGGER2_DEBUG} || 0;
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 # Should be considered internal
 our @SPEC_FILE = (File::Spec->splitdir(File::Basename::dirname(__FILE__)), 'Swagger2', 'schema.json');
@@ -354,7 +354,7 @@ sub _load {
   }
 
   # try to read processed spec from file cache
-  my $file = File::Spec->catfile(CACHE_DIR, md5_sum $namespace);
+  my $file = File::Spec->catfile(CACHE_DIR, md5_sum($namespace->to_string));
   my $doc = -r $file ? Mojo::Util::slurp($file) : '';
   my $type;
 
@@ -371,7 +371,8 @@ sub _load {
       $doc  = $tx->res->body;
       $type = lc $1 if $url->path =~ /\.(\w+)$/;
       $type = lc $1 if +($tx->res->headers->content_type // '') =~ /(json|yaml)/i;
-      Mojo::Util::spurt($doc, File::Spec->catfile(CACHE_DIR, md5_sum $namespace)) if CACHE_DIR and -w CACHE_DIR;
+      Mojo::Util::spurt($doc, File::Spec->catfile(CACHE_DIR, md5_sum($namespace->to_string)))
+        if CACHE_DIR and -w CACHE_DIR;
     }
   }
 
